@@ -10,6 +10,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                     comb.fixed=TRUE, comb.random=TRUE,
                     hakn=FALSE,
                     method.tau="DL", tau.preset=NULL, TE.tau=NULL,
+                    tau.common=FALSE,
+                    prediction=FALSE, level.predict=level,
                     method.bias=NULL,
                     title="", complab="", outclab="",
                     label.e="Experimental", label.c="Control",
@@ -28,7 +30,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   mf$data <- mf$subset <- mf$method <- mf$sm <- NULL
   mf$incr <- mf$allincr <- mf$addincr <- mf$allstudies <- NULL
   mf$MH.exact <- mf$RR.cochrane <- NULL
-  mf$level <- mf$level.comb <- mf$warn <- NULL
+  mf$level <- mf$level.comb <- mf$level.predict <- mf$prediction <- mf$warn <- NULL
   mf$hakn <- mf$method.tau <- mf$tau.preset <- mf$TE.tau <- mf$method.bias <- NULL
   mf[[1]] <- as.name("data.frame")
   mf <- eval(mf, data)
@@ -42,7 +44,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   mf2$data <- mf2$method <- mf2$sm <- NULL
   mf2$incr <- mf2$allincr <- mf2$addincr <- mf2$allstudies <- NULL
   mf2$MH.exact <- mf2$RR.cochrane <- NULL
-  mf2$level <- mf2$level.comb <- mf2$warn <- NULL
+  mf2$level <- mf2$level.comb <- mf2$level.predict <- mf2$prediction <- mf2$warn <- NULL
   mf2$hakn <- mf2$method.tau <- mf2$tau.preset <- mf2$TE.tau <- mf2$method.bias <- NULL
   mf2$byvar <- NULL
   mf2[[1]] <- as.name("data.frame")
@@ -61,7 +63,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   event.c <- mf$event.c
   n.c     <- mf$n.c
   ##
-  if (!missing(byvar)){
+  missing.byvar <- missing(byvar)
+  if (!missing.byvar){
     byvar.name <- deparse(substitute(byvar))
     byvar <- mf$byvar
   }
@@ -123,6 +126,11 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     stop("parameter 'level.comb' must be a numeric of length 1")
   if (level.comb <= 0 | level.comb >= 1)
     stop("parameter 'level.comb': no valid level for confidence interval")
+  ##
+  if (!is.numeric(level.predict) | length(level.predict)!=1)
+    stop("parameter 'level.predict' must be a numeric of length 1")
+  if (level.predict <= 0 | level.predict >= 1)
+    stop("parameter 'level.predict': no valid level for confidence interval")
   
   
   if (sm == "AS") method <- "Inverse"
@@ -169,6 +177,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   if (is.integer(event.c)) event.c <- as.numeric(event.c)
   if (is.integer(n.c))     n.c     <- as.numeric(n.c)
   
+  
   ##
   ##
   ## Include non-informative studies?
@@ -395,16 +404,42 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ## for inverse variance and Peto method
   ##
   ##
-  if (method == "Inverse" || method=="Peto"){
-    if (method == "Inverse")
+  if (method == "Inverse" || method== "Peto"){
+    if (method == "Inverse"){
+      ## Subgroup analysis with equal tau^2:
+      if (!missing.byvar & tau.common){
+        if (!is.null(tau.preset))
+          warning("Value for argument 'tau.preset' not considered as argument 'tau.common=TRUE'")
+        ##
+        sm1 <- summary(metagen(TE, seTE, byvar=byvar,
+                               method.tau=method.tau,
+                               tau.common=tau.common))
+        sQ.w <- sum(sm1$Q.w)
+        sk.w <- sum(sm1$k.w-1)
+        sC.w <- sum(sm1$C.w)
+        ##
+        if (round(sQ.w, digits=18)<=sk.w) tau2 <- 0
+        else tau2 <- (sQ.w-sk.w)/sC.w
+        tau.preset <- sqrt(tau2)
+      }
+      ##
       if (!is.null(tau.preset))
         m <- metagen(TE, seTE,
                      hakn=hakn, method.tau=method.tau,
-                     tau.preset=tau.preset, TE.tau=TE.tau)
+                     tau.preset=tau.preset, TE.tau=TE.tau,
+                     level=level,
+                     level.comb=level.comb,
+                     prediction=prediction,
+                     level.predict=level.predict)
       else
         m <- metagen(TE, seTE,
                      hakn=hakn, method.tau=method.tau,
-                     TE.tau=TE.tau)
+                     TE.tau=TE.tau,
+                     level=level,
+                     level.comb=level.comb,
+                     prediction=prediction,
+                     level.predict=level.predict)
+    }
     ##
     if (method == "Peto"){
       if (method.tau!="DL"){
@@ -425,13 +460,23 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
         TE.tau <- NULL
       }
       ##
+      if (tau.common){
+        if (warn)
+          warning("Argument 'tau.common' not considered for Peto method")
+        tau.common <- FALSE
+      }
+      ##
       if (!is.null(tau.preset)){
         if (warn)
           warning("Argument 'tau.preset' not considered for Peto method")
         tau.preset <- NULL
       }
       ##
-      m <- metagen(TE, seTE)
+      m <- metagen(TE, seTE,
+                   level=level,
+                   level.comb=level.comb,
+                   prediction=prediction,
+                   level.predict=level.predict)
     }
     ##
     TE.fixed <- m$TE.fixed
@@ -455,6 +500,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     Q <- m$Q
     tau2 <- m$tau^2
     se.tau2 <- m$se.tau2
+    Cval <- m$C
   }
   
   
@@ -478,6 +524,10 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
       hakn <- FALSE
     }
     ##
+    if (!missing.byvar & tau.common)
+      if (warn)
+        warning("Argument 'tau.common' not considered for Mantel Haenszel method")
+    ##
     if (!is.null(TE.tau)){
       if (warn)
         warning("Argument 'TE.tau' not considered for Mantel Haenszel method")
@@ -557,21 +607,25 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     lower.fixed <- ci.f$lower
     upper.fixed <- ci.f$upper
     
-    
-    m.MH <- metagen(TE, seTE, method.tau="DL", TE.tau=TE.fixed)
+    m <- metagen(TE, seTE, method.tau="DL", TE.tau=TE.fixed,
+                 level=level,
+                 level.comb=level.comb,
+                 prediction=prediction,
+                 level.predict=level.predict)
     ##
-    TE.random <- m.MH$TE.random
-    seTE.random <- m.MH$seTE.random
-    w.random <- m.MH$w.random
+    TE.random <- m$TE.random
+    seTE.random <- m$seTE.random
+    w.random <- m$w.random
     ##
-    zval.random <- m.MH$zval.random
-    pval.random <- m.MH$pval.random
-    lower.random <- m.MH$lower.random
-    upper.random <- m.MH$upper.random
+    zval.random <- m$zval.random
+    pval.random <- m$pval.random
+    lower.random <- m$lower.random
+    upper.random <- m$upper.random
     ##
-    Q <- m.MH$Q
-    se.tau2 <- m.MH$se.tau2
-    tau2 <- m.MH$tau^2
+    Q <- m$Q
+    se.tau2 <- m$se.tau2
+    tau2 <- m$tau^2
+    Cval <- m$C
   }
   
   
@@ -588,19 +642,43 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   w.fixed[is.na(w.fixed)] <- 0
   
   
+  if (m$k>=3){
+    seTE.predict <- sqrt(m$seTE.random^2 + m$tau^2)
+    ci.p <- ci(m$TE.random, seTE.predict, level.predict, m$k-2)
+    p.lower <- ci.p$lower
+    p.upper <- ci.p$upper
+  }
+  else{
+    seTE.predict <- NA
+    p.lower <- NA
+    p.upper <- NA
+  }
+  
+  
+  if (!missing.byvar & tau.common)
+    tau.preset <- NULL
+  
+  
   res <- list(event.e=event.e, n.e=n.e,
               event.c=event.c, n.c=n.c,
               studlab=studlab,
               TE=TE, seTE=seTE,
               w.fixed=w.fixed,
               w.random=w.random,
+              ##
               TE.fixed=TE.fixed, seTE.fixed=seTE.fixed,
               lower.fixed=lower.fixed, upper.fixed=upper.fixed,
               zval.fixed=zval.fixed, pval.fixed=pval.fixed,
               TE.random=TE.random, seTE.random=seTE.random,
               lower.random=lower.random, upper.random=upper.random,
               zval.random=zval.random, pval.random=pval.random,
+              ##
+              seTE.predict=seTE.predict,
+              lower.predict=p.lower, upper.predict=p.upper,
+              level.predict=level.predict,
+              ##
               k=k, Q=Q, tau=sqrt(tau2), se.tau2=se.tau2,
+              C=Cval,
               Q.CMH=Q.CMH,
               sm=sm, method=method,
               sparse=sparse,
@@ -621,6 +699,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
               method.tau=method.tau,
               tau.preset=tau.preset,
               TE.tau=if (!is.null(TE.tau) & method.tau=="DL") TE.tau else NULL,
+              tau.common=tau.common,
+              prediction=prediction,
               method.bias=method.bias,
               title=title,
               complab=complab,
