@@ -5,6 +5,8 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                      comb.fixed=TRUE, comb.random=TRUE,
                      hakn=FALSE,
                      method.tau="DL", tau.preset=NULL, TE.tau=NULL,
+                     tau.common=FALSE,
+                     prediction=FALSE, level.predict=level,
                      method.bias="linreg",
                      title="", complab="", outclab="",
                      label.e="Experimental", label.c="Control",
@@ -20,7 +22,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   ##
   mf <- match.call()
   mf$data <- mf$subset <- mf$sm <- NULL
-  mf$level <- mf$level.comb <- NULL
+  mf$level <- mf$level.comb <- mf$level.predict <- mf$prediction <- NULL
   mf$hakn <- mf$method.tau <- mf$tau.preset <- mf$TE.tau <- mf$method.bias <- NULL
   mf[[1]] <- as.name("data.frame")
   mf <- eval(mf, data)
@@ -32,7 +34,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   mf2$n.c <- mf2$mean.c <- mf2$sd.c <- NULL
   mf2$studlab <- NULL 
   mf2$data <- mf2$sm <- NULL
-  mf2$level <- mf2$level.comb <- NULL
+  mf2$level <- mf2$level.comb <- mf2$level.predict <- mf2$prediction <- NULL
   mf2$hakn <- mf2$method.tau <- mf2$tau.preset <- mf2$TE.tau <- mf2$method.bias <- NULL
   mf2$byvar <- NULL
   mf2[[1]] <- as.name("data.frame")
@@ -58,7 +60,8 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   mean.c  <- mf$mean.c
   sd.c    <- mf$sd.c
   ##
-  if (!missing(byvar)){
+  missing.byvar <- missing(byvar)
+  if (!missing.byvar){
     byvar.name <- deparse(substitute(byvar))
     byvar <- mf$byvar
   }
@@ -119,6 +122,11 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
     stop("parameter 'level.comb' must be a numeric of length 1")
   if (level.comb <= 0 | level.comb >= 1)
     stop("parameter 'level.comb': no valid level for confidence interval")
+  ##
+  if (!is.numeric(level.predict) | length(level.predict)!=1)
+    stop("parameter 'level.predict' must be a numeric of length 1")
+  if (level.predict <= 0 | level.predict >= 1)
+    stop("parameter 'level.predict': no valid level for confidence interval")
   
   
   if (sm == "MD"){
@@ -161,14 +169,59 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   if (is.integer(sd.c))   sd.c   <- as.numeric(sd.c)
   
   
+  ##
+  ## Subgroup analysis with equal tau^2:
+  ##
+  if (!missing.byvar & tau.common){
+    if (!is.null(tau.preset))
+      warning("Value for argument 'tau.preset' not considered as argument 'tau.common=TRUE'")
+    ##
+    sm1 <- summary(metagen(TE, seTE, byvar=byvar,
+                           method.tau=method.tau,
+                           tau.common=tau.common))
+    sQ.w <- sum(sm1$Q.w)
+    sk.w <- sum(sm1$k.w-1)
+    sC.w <- sum(sm1$C.w)
+    ##
+    if (round(sQ.w, digits=18)<=sk.w) tau2 <- 0
+    else tau2 <- (sQ.w-sk.w)/sC.w
+    tau.preset <- sqrt(tau2)
+  }
+  
+  
   if (!is.null(tau.preset))
     m <- metagen(TE, seTE,
                  hakn=hakn, method.tau=method.tau,
-                 tau.preset=tau.preset, TE.tau=TE.tau)
+                 tau.preset=tau.preset, TE.tau=TE.tau,
+                 level=level,
+                 level.comb=level.comb,
+                 prediction=prediction,
+                 level.predict=level.predict)
   else
     m <- metagen(TE, seTE,
                  hakn=hakn, method.tau=method.tau,
-                 TE.tau=TE.tau)
+                 TE.tau=TE.tau,
+                 level=level,
+                 level.comb=level.comb,
+                 prediction=prediction,
+                 level.predict=level.predict)
+  
+  
+  if (m$k>=3){
+    seTE.predict <- sqrt(m$seTE.random^2 + m$tau^2)
+    ci.p <- ci(m$TE.random, seTE.predict, level.predict, m$k-2)
+    p.lower <- ci.p$lower
+    p.upper <- ci.p$upper
+  }
+  else{
+    seTE.predict <- NA
+    p.lower <- NA
+    p.upper <- NA
+  }
+  
+  
+  if (!missing.byvar & tau.common)
+    tau.preset <- NULL
   
   
   res <- list(n.e=n.e, mean.e=mean.e, sd.e=sd.e,
@@ -176,13 +229,20 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
               studlab=studlab,
               TE=TE, seTE=seTE,
               w.fixed=m$w.fixed, w.random=m$w.random,
+              ##
               TE.fixed=m$TE.fixed, seTE.fixed=m$seTE.fixed,
               lower.fixed=m$lower.fixed, upper.fixed=m$upper.fixed,
               zval.fixed=m$zval.fixed, pval.fixed=m$pval.fixed,
               TE.random=m$TE.random, seTE.random=m$seTE.random,
               lower.random=m$lower.random, upper.random=m$upper.random,
               zval.random=m$zval.random, pval.random=m$pval.random,
+              ##
+              seTE.predict=seTE.predict,
+              lower.predict=p.lower, upper.predict=p.upper,
+              level.predict=level.predict,
+              ##
               k=m$k, Q=m$Q, tau=m$tau, se.tau2=m$se.tau2,
+              C=m$C,
               sm=sm, method=m$method,
               level=level,
               level.comb=level.comb,
@@ -193,6 +253,8 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
               method.tau=method.tau,
               tau.preset=tau.preset,
               TE.tau=if (!missing(TE.tau) & method.tau=="DL") TE.tau else NULL,
+              tau.common=tau.common,
+              prediction=prediction,
               method.bias=method.bias,
               title=title,
               complab=complab,
