@@ -266,6 +266,9 @@ metaprop <- function(event, n, studlab,
               C=m$C,
               sm=sm,
               method=m$method,
+              incr=incr.event,
+              allincr=allincr,
+              addincr=addincr,
               level=level, level.comb=level.comb,
               comb.fixed=comb.fixed,
               comb.random=comb.random,
